PALM-meteo: palmmeteo.logging.LoggingLevel Class Reference

PALM-meteo

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
palmmeteo.logging.LoggingLevel Class Reference

## Public Member Functions
| __init__ (self, is_on, use_dt=False)
| __call__ (self, s, *args, **kwargs)
| __bool__ (self)

## Public Attributes
| is_on
| use_dt

## Constructor & Destructor Documentation

## ◆ __init__()

palmmeteo.logging.LoggingLevel.__init__ | ( |  | self,
|  |  | is_on,
|  |  | use_dt = `False`
| ) |  |

## Member Function Documentation

## ◆ __bool__()

palmmeteo.logging.LoggingLevel.__bool__ | ( |  | self | ) |

## ◆ __call__()

palmmeteo.logging.LoggingLevel.__call__ | ( |  | self,
|  |  | s,
|  | * | args,
|  | ** | kwargs
| ) |  |

    Write logging or debugging message with optional datetime if configured to do so.

## Member Data Documentation

## ◆ is_on

palmmeteo.logging.LoggingLevel.is_on

## ◆ use_dt

palmmeteo.logging.LoggingLevel.use_dt

The documentation for this class was generated from the following file:

- palmmeteo/logging.py